function [W,lambdaValues] = computeL1Generalpath(X,y,lambdaValues,nonZeroCols)

plotOn = 0;

nLambdaValues = length(lambdaValues);
nVars = size(X,2);
nInstances = size(X,1);
w = zeros(nVars,1);

% Solve for bias
w(1) = log(sum(y==1)/sum(y==-1));

[f,g] = LogisticLoss(w,X,y);
lambdaMax = max(abs(g));

%% Now solve the problems, using warm-starting
W = zeros(nVars,nLambdaValues);
lambdaVect = [0;ones(nVars-1,1)]; % Pattern of the lambda vector
for i = 1:nLambdaValues
    lambda = lambdaValues(i);
    fprintf('lambda = %f\n',lambda);
    
    % Compute free variables (uses w and g from above)
    free = lambdaVect == 0 | w ~= 0 | (w == 0 & (abs(g) > lambda));
        
    while 1
        
        % Solve with respect to free variables
        funObj = @(w)LogisticLoss(w,X(:,free),y);
        w(free) = L1General2_PSSgb(funObj,w(free),lambda*lambdaVect(free));
        
        % Compute new set of free variables
        [f,g] = LogisticLoss(w,X,y);
        free_new = lambdaVect == 0 | w ~= 0 | (w == 0 & (abs(g) > lambda));
        
        if any(free_new == 1 & free == 0)
            % We added a new free variable, re-optimize
            free = free_new;
        else
            % Optimal solution found
            break;
        end
    end
    
    % Record solution
    W(:,i) = w;
end

if plotOn
    % Plot regularization path
    fprintf('Regularization path calculation done, plotting...\n');
    figure;
    plot(lambdaValues,W);
    legend('Bias');
    title('Regularization Path');
    figure;
    plot(lambdaValues,W);
    xlim([lambdaValues(end) lambdaValues(1)]);
    ylim([-.1 .1]);
    title('Regularization Path (close to zero)');
end