function [acc,labelsEstim,prob,KE] = evaluate_prob_bilinear(data,labelsTrue,V,W,Ra)

% Evaluate probabilities of the category memberships for bilinear
% classifier. Estimate category labels based on these probabilities.
%
% Inputs:
%
% data - test data for the classifier. This is a tensor of size F*N*C, where:
% F is the number of frequency bin in each epoch
% N is the total number of epochs
% C is the total number of channels or components
% 
% labelsTrue - a vector of length N denoting class labels of each epoch. 
% Categories are indexed as 1,2,3,...,K, where K is the total number of categories.
% 
% V - estimated classifier "V" parameters
% W - estimated classifier "W" parameters
% Ra - rank of the bilinear classifier
% 
% Outputs:
%
% acc - classification accuracy
% labelsEstim - estimated class labels for each epoch
% prob - estimated posterior probabilities for each epoch
% KE - value of the bilinear Kernel-function

prob = NaN*zeros(size(V,2),size(data,2));
K = zeros(size(prob));
for nn = 1:size(data,2)
    KE(nn) = 0;
    Wr = reshape(W,length(W)/Ra,Ra);
    Vr = reshape(V,length(V)/Ra,Ra);
    for gg = 1:Ra
        KE(nn) = KE(nn) + Wr(:,gg)'*squeeze(data(:,nn,:))*Vr(:,gg);
    end
end
KE = -KE;
prob = 1./(1+exp(KE));
labelsEstim = 1+(prob < 0.5);
labelsTrue = repmat(labelsTrue(:)',size(labelsEstim,1),1);
acc = sum(labelsEstim == labelsTrue,2)/size(labelsEstim,2);
