function plot_array(M,mapType,pos_map,phasemap_th)
% This function visualizes component maps over spatial grid. Depending on 
% chosen map type, either magnitude or phase map can be visualized.
%
% Inputs:
%
% M (matrix or vector) - spatial pattern of component as vector form. 
% When P spatial patterns are visualized, M is a matrix of size C*P, where
% C is the number of sensors.
% mapType (string) - Determines the type (magnitude or phase map) of the 
% plotted map. Value must be either 'magnitude' or 'phase'.
% pos_map (matrix) - position map of the sensors in 2D spatial grid.


%phasemap_th = 0.25; % phase map threshold

n = size(M,1);


for component = 1:n
    
    [locations,locationsPhase] = get_locations(M(component,:));   
    locations = locations - min(locations);
    locations = locations/max(locations);
    P.colorbar = 0;    
    if n > 1
        subplot(n/2,2,component);
    end
    switch mapType
        case 'magnitude'
            P.colormap = 'jet';
            P.interpol = 'cubic';
            [h_ampl,colBar] = colorplot_universal_modif(locations',pos_map,P);
        case 'phase'
            P.colormap = 'hsv';   
            P.interpol = 'nearest';            
            slocations = sort(locations,'descend');
            locationsPhase(locations < phasemap_th) = 0;
            [h_ampl2,colBar2] = colorplot_universal_modif(locationsPhase',pos_map,P);
        otherwise
            error('Wrong map type!')
    end    
end
