function resu = test_sparse_bilinear(data,labels,Classifier)
% Test sparse bilinear classifier.
%
% Inputs:
% 
% data - test data for the classifier. This is a tensor of size C*N*F, where:
% C is the total number of channels or independent components
% N is the total number of epochs
% F is the number of frequency bins in each epoch
% 
% labels - a vector of length N denoting class labels of each epoch. 
% Categories are indexed as 1,2,3,...,K, where K is the total number of categories.
%
% Classifier - classifier parameters estimated by "train_sparse_bilinear".
% 
% Outputs:
%
% resu - a struct containing testing results:
%    resu.acc           classification accuracy
%    resu.labelsEstim   estimated class labels
%    resu.labelsTrue    true class labels


% init variables and data structs:
V = Classifier.V;
W = Classifier.W;
Ra = Classifier.Rank;
if Classifier.number_of_categories == 2
    nClasses = 1;
else
    nClasses = Classifier.number_of_categories;
end
data = permute(data,[3 2 1]);

labelsTrue = labels(:);

Proj = zeros(size(data,2),nClasses);
acc = zeros(1,nClasses);

for m = 1:nClasses
    y = 1 + (labels == m); % binary class indicator vector
    [acc(m),labelsEstim,pr,Proj(:,m)] = evaluate_prob_bilinear(data,y,W{m}(2:end),V{m}(2:end),Ra);
end

% In multicategory case, perform multi-category classification based on 
% one-vs-rest classifiers:
if nClasses > 1
    [ma,labelsEstim] = max(Proj,[],2);
    labelsEstim = labelsEstim(:);
    acc = sum(labelsTrue == labelsEstim)/length(labelsTrue);
end

% save results:
resu.acc = acc;
resu.labelsEstim = labelsEstim;
resu.labelsTrue = labelsTrue;
