function visualize_patterns(ICvec,phasemap_th,A,pos_map,plot_colorbar,titl)
% Visualization of the spatial patterns (magnitude and phase) of the 
% independent components.

% Inputs:
%
% ICvec - A two-row matrix where the first row contains indices of the independent
% components (ICs), and the second row contains the corresponding classification
% coefficient of the ICs.
% A - spatial patterns of all the ICs
% pos_map - position map of the electrode array
% plot_colorbar - plot (plot_colorbar = 1) or don't plot (plot_colorbar = 0) colorbar.
% titl - name of the figure

IC_index = ICvec(1,:);
coeffVals = abs(ICvec(2,:));

% plot at most 10 components:
[coeffVals,sinds] = sort(coeffVals,'descend');
IC_index = IC_index(sinds);
if length(IC_index) > 10
    coeffVals = coeffVals(1:10);
    IC_index = IC_index(1:10);
    warning('Plotting 10 most relevant components only...')
end
largeInds = find(coeffVals>0.05);

coeffVals = coeffVals(largeInds);
IC_index = IC_index(largeInds);

% % ignore components with very small coefficient values:
% coeffVals = coeffVals(coeffVals>0.05);
% 
% % plot at most 10 components:
% [coeffVals,sinds] = sort(coeffVals,'descend');
% IC_index = IC_index(sinds);
% if length(IC_index) > 10
%     coeffVals = coeffVals(1:10);
%     IC_index = IC_index(1:10);
%     warning('Plotting 10 most relevant components only...')
% end

% plot magnitude maps:
figure
set(gcf,'Position',[30 70 610 560],'name',titl)
for m = 1:length(coeffVals)
    if length(IC_index) > 5
        subplot(5,2,m)        
    else
        subplot(length(IC_index),1,m)
    end
    ICApatterns = A(:,IC_index(m));    
    % actual plotting commands are executed here:
    plot_array(ICApatterns','magnitude',pos_map);
    title(['Magnitude of component #' num2str(IC_index(m)) ', coeff: ' num2str(round(100*coeffVals(m))/100)])
    % alternatively, plot component index with the stability value:
    % title(['Component #' num2str(coefAll(m)) ', magnitude, stability: ' num2str(compSorted(m)/maxCount)])
end
cmap1 = get(gcf,'Colormap');

% plot phase maps:
figure
set(gcf,'Position',[670 70 610 560],'name',titl)
for m = 1:length(coeffVals)
    if length(IC_index) > 5
        subplot(5,2,m)        
    else
        subplot(length(IC_index),1,m)
    end
    ICApatterns = A(:,IC_index(m));    
    plot_array(ICApatterns','phase',pos_map,phasemap_th);
    %title(['Component #' num2str(coeffVals(m)) ', phase'])
    title(['Phase of component #' num2str(IC_index(m)) ', coeff: ' num2str(round(100*coeffVals(m))/100)])
    % alternatively, plot component index with the stability value:
    % title(['Component #' num2str(coefAll(m)) ', phase, stability: ' num2str(compSorted(m)/maxCount)])
end
cmap2 = get(gcf,'Colormap');

% plot colorbars:
if plot_colorbar
    figure;set(gcf,'Colormap',cmap1);
    h = colorbar('NorthOutside');set(h,'XTickLabel',[])
    title('Colorbar for magnitude plots: [0,...,1]');axis off;    
    figure;set(gcf,'Colormap',cmap2);
    h = colorbar('NorthOutside');set(h,'XTickLabel',[])
    title('Colorbar for phase plots: [-\pi/2,...,\pi/2]');axis off;
end
